==> apache-camel-4.8.0-src.zip: apache-camel-4.8.0/components/camel-tarfile/src/test/java/org/apache/camel/dataformat/tarfile/TarFileSplitAndDeleteTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.tarfile;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.Iterator;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.NotifyBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.apache.camel.test.junit5.TestSupport.deleteDirectory;
import static org.junit.jupiter.api.Assertions.assertFalse;

public class TarFileSplitAndDeleteTest extends CamelTestSupport {

    @Override
    public void doPreSetup() {
        deleteDirectory("target/testDeleteTarFileWhenUnmarshalWithDataFormat");
        deleteDirectory("target/testDeleteTarFileWhenUnmarshalWithSplitter");
    }

    @Test
    public void testDeleteTarFileWhenUnmarshalWithDataFormat() throws Exception {
        NotifyBuilder notify = new NotifyBuilder(context)
                .from("file://target/" + "testDeleteTarFileWhenUnmarshalWithDataFormat").whenDone(1).create();
        getMockEndpoint("mock:end").expectedMessageCount(3);
        String tarFile = createTarFile("testDeleteTarFileWhenUnmarshalWithDataFormat");

        MockEndpoint.assertIsSatisfied(context);

        notify.matchesWaitTime();

        // the original file should have been deleted
        assertFalse(new File(tarFile).exists(), "File should been deleted");
    }

    @Test
    public void testDeleteTarFileWhenUnmarshalWithSplitter() throws Exception {
        NotifyBuilder notify = new NotifyBuilder(context).from("file://target/" + "testDeleteTarFileWhenUnmarshalWithSplitter")
                .whenDone(1).create();
        getMockEndpoint("mock:end").expectedMessageCount(3);
        String tarFile = createTarFile("testDeleteTarFileWhenUnmarshalWithSplitter");

        MockEndpoint.assertIsSatisfied(context);

        notify.matchesWaitTime();

        // the original file should have been deleted,
        assertFalse(new File(tarFile).exists(), "File should been deleted");
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                TarFileDataFormat dataFormat = new TarFileDataFormat();
                dataFormat.setUsingIterator(true);

                from("file://target/testDeleteTarFileWhenUnmarshalWithDataFormat?delete=true")
                        .unmarshal(dataFormat)
                        .split(bodyAs(Iterator.class)).streaming()
                            .convertBodyTo(String.class)
                            .to("mock:end")
                        .end();

                from("file://target/testDeleteTarFileWhenUnmarshalWithSplitter?delete=true")
                        .split(new TarSplitter()).streaming()
                            .convertBodyTo(String.class)
                            .to("mock:end")
                        .end();
            }
        };
    }

    private String createTarFile(String folder) throws IOException {
        Path source = Paths.get("src/test/resources/data/tarfile3.tar");
        Path target = Paths.get("target" + File.separator + folder + File.separator + "data.tar");
        target.toFile().getParentFile().mkdirs();
        Path copy = Files.copy(source, target, StandardCopyOption.REPLACE_EXISTING);
        return copy.toAbsolutePath().toString();
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-tarfile/src/test/java/org/apache/camel/dataformat/tarfile/TarFileSplitAndDeleteTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.tarfile;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.Iterator;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.NotifyBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.apache.camel.test.junit5.TestSupport.deleteDirectory;
import static org.junit.jupiter.api.Assertions.assertFalse;

class TarFileSplitAndDeleteTest extends CamelTestSupport {

    @BeforeEach
    public void cleanOutputDirectories() {
        deleteDirectory("target/testDeleteTarFileWhenUnmarshalWithDataFormat");
        deleteDirectory("target/testDeleteTarFileWhenUnmarshalWithSplitter");
    }

    @Test
    void testDeleteTarFileWhenUnmarshalWithDataFormat() throws Exception {
        NotifyBuilder notify = new NotifyBuilder(context)
                .from("file://target/" + "testDeleteTarFileWhenUnmarshalWithDataFormat").whenDone(1).create();
        getMockEndpoint("mock:end").expectedMessageCount(3);
        String tarFile = createTarFile("testDeleteTarFileWhenUnmarshalWithDataFormat");

        MockEndpoint.assertIsSatisfied(context);

        notify.matchesWaitTime();

        // the original file should have been deleted
        assertFalse(new File(tarFile).exists(), "File should been deleted");
    }

    @Test
    void testDeleteTarFileWhenUnmarshalWithSplitter() throws Exception {
        NotifyBuilder notify = new NotifyBuilder(context).from("file://target/" + "testDeleteTarFileWhenUnmarshalWithSplitter")
                .whenDone(1).create();
        getMockEndpoint("mock:end").expectedMessageCount(3);
        String tarFile = createTarFile("testDeleteTarFileWhenUnmarshalWithSplitter");

        MockEndpoint.assertIsSatisfied(context);

        notify.matchesWaitTime();

        // the original file should have been deleted,
        assertFalse(new File(tarFile).exists(), "File should been deleted");
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                TarFileDataFormat dataFormat = new TarFileDataFormat();
                dataFormat.setUsingIterator(true);

                from("file://target/testDeleteTarFileWhenUnmarshalWithDataFormat?delete=true")
                        .unmarshal(dataFormat)
                        .split(bodyAs(Iterator.class)).streaming()
                            .convertBodyTo(String.class)
                            .to("mock:end")
                        .end();

                from("file://target/testDeleteTarFileWhenUnmarshalWithSplitter?delete=true")
                        .split(new TarSplitter()).streaming()
                            .convertBodyTo(String.class)
                            .to("mock:end")
                        .end();
            }
        };
    }

    private String createTarFile(String folder) throws IOException {
        Path source = Paths.get("src/test/resources/data/tarfile3.tar");
        Path target = Paths.get("target" + File.separator + folder + File.separator + "data.tar");
        target.toFile().getParentFile().mkdirs();
        Path copy = Files.copy(source, target, StandardCopyOption.REPLACE_EXISTING);
        return copy.toAbsolutePath().toString();
    }
}
